@@ -107,6 +107,15 @@ void crypt_init (void)
 #endif
 }
 
+void crypt_cleanup (void)
+{
+  if (CRYPT_MOD_CALL_CHECK (PGP, cleanup))
+    (CRYPT_MOD_CALL (PGP, cleanup)) ();
+
+  if (CRYPT_MOD_CALL_CHECK (SMIME, cleanup))
+    (CRYPT_MOD_CALL (SMIME, cleanup)) ();
+}
+
 
 /* Show a message that a backend will be invoked. */
 void crypt_invoke_message (int type)
@@ -315,12 +324,10 @@ int crypt_pgp_verify_one (BODY *sigbdy, STATE *s, const char *tempf)
 }
 
 
-int crypt_pgp_send_menu (HEADER *msg)
+void crypt_pgp_send_menu (SEND_CONTEXT *sctx)
 {
   if (CRYPT_MOD_CALL_CHECK (PGP, send_menu))
-    return (CRYPT_MOD_CALL (PGP, send_menu)) (msg);
-
-  return 0;
+    (CRYPT_MOD_CALL (PGP, send_menu)) (sctx);
 }
 
 
@@ -449,12 +456,10 @@ int crypt_smime_verify_one (BODY *sigbdy, STATE *s, const char *tempf)
   return -1;
 }
 
-int crypt_smime_send_menu (HEADER *msg)
+void crypt_smime_send_menu (SEND_CONTEXT *sctx)
 {
   if (CRYPT_MOD_CALL_CHECK (SMIME, send_menu))
-    return (CRYPT_MOD_CALL (SMIME, send_menu)) (msg);
-
-  return 0;
+    (CRYPT_MOD_CALL (SMIME, send_menu)) (sctx);
 }
 
 void crypt_smime_set_sender (const char *sender)
