@@ -808,7 +808,10 @@ void mutt_pop_current_menu (MUTTMENU *menu)
   if (prev_menu)
   {
     CurrentMenu = prev_menu->menu;
-    prev_menu->redraw = REDRAW_FULL;
+    /* REDRAW_FLOW is for the pager, which needs to reflow if
+     * a window resize or setting change occurred.
+     */
+    prev_menu->redraw = REDRAW_FULL | REDRAW_FLOW;
   }
   else
   {
@@ -856,7 +859,7 @@ void mutt_set_menu_redraw_full (int menu_type)
     mutt_set_current_menu_redraw_full ();
 }
 
-void mutt_current_menu_redraw ()
+void mutt_current_menu_redraw (void)
 {
   MUTTMENU *current_menu;
 
@@ -1044,6 +1047,20 @@ int mutt_menuLoop (MUTTMENU *menu)
 
     mutt_curs_set (0);
 
+#if defined (USE_SLANG_CURSES) || defined (HAVE_RESIZETERM)
+    if (SigWinch)
+    {
+      do
+      {
+        SigWinch = 0;
+        mutt_resize_screen ();
+      }
+      while (SigWinch);
+
+      clearok(stdscr,TRUE);/*force complete redraw*/
+    }
+#endif
+
     if (menu->custom_menu_update)
       menu->custom_menu_update (menu);
 
@@ -1107,15 +1124,6 @@ int mutt_menuLoop (MUTTMENU *menu)
 
     mutt_curs_set (1);
 
-#if defined (USE_SLANG_CURSES) || defined (HAVE_RESIZETERM)
-    if (SigWinch)
-    {
-      SigWinch = 0;
-      mutt_resize_screen ();
-      clearok(stdscr,TRUE);/*force complete redraw*/
-    }
-#endif
-
     if (i < 0)
     {
       if (menu->tagprefix)
