@@ -388,7 +388,7 @@ static const char *mix_entry_fmt (char *dest,
 				  const char *prefix,
 				  const char *ifstring,
 				  const char *elsestring,
-				  unsigned long data,
+				  void *data,
 				  format_flag flags)
 {
   char fmt[16];
@@ -447,7 +447,7 @@ static void mix_entry (char *b, size_t blen, MUTTMENU *menu, int num)
 {
   REMAILER **type2_list = (REMAILER **) menu->data;
   mutt_FormatString (b, blen, 0, MuttIndexWindow->cols, NONULL (MixEntryFormat), mix_entry_fmt,
-		     (unsigned long) type2_list[num], MUTT_FORMAT_ARROWCURSOR);
+		     type2_list[num], MUTT_FORMAT_ARROWCURSOR);
 }
 
 static int mix_chain_add (MIXCHAIN *chain, const char *s,
